/**	@file	he-ulongso.c	Unsigned long zu String konvertieren.
*/

/* Copyright (C) 2014 - HS Schmalkalden. All rights reserved. */

#include "he-conf.h"

#if HAVE_STDLIB_H
#include <stdlib.h>
#endif
#if HAVE_STDINT_H
#include <stdint.h>
#endif
#if HAVE_LIMITS_H
#include <limits.h>
#endif

#include "he-ulongso.h"
#include "he-error.h"



int
hsm_et_ulong_to_string(char *rb, size_t sz, unsigned long ul, int *ec)
{
  char          buffer[4 * (sizeof(long) + 4)]; /* Temporaerer Puffer */
  size_t        used    =   0;      /* Anzahl der bereits benutzten Bytes */
  size_t        i;                  /* Umkehr des Puffers */
  unsigned long rem;                /* Aktueller Rest */
  int           back    =   0;      /* Ergebnis der Funktion */

  if ((NULL != rb) && (0 < sz)) {

    /*  In temporaeren Puffer den reversen String aufbauen.
    */
    do {
      rem = ul % 10UL;
      ul  = ul / 10UL;
      switch((int)rem) {
        case 0: {
          buffer[used++] = '0';
        } break;
        case 1: {
          buffer[used++] = '1';
        } break;
        case 2: {
          buffer[used++] = '2';
        } break;
        case 3: {
          buffer[used++] = '3';
        } break;
        case 4: {
          buffer[used++] = '4';
        } break;
        case 5: {
          buffer[used++] = '5';
        } break;
        case 6: {
          buffer[used++] = '6';
        } break;
        case 7: {
          buffer[used++] = '7';
        } break;
        case 8: {
          buffer[used++] = '8';
        } break;
        case 9: {
          buffer[used++] = '9';
        } break;
      }
    } while(0UL < ul);

    /*  Temporaeren Puffer in Zielpuffer kopieren, dabei Reihenfolge
        der Zeichen umdrehen.
        Falls Zielpuffer zu klein, dann leeren String schaffen.
    */
    if (used < sz) {
      back = 1;
      for (i = 0; i < used; i++) {
        rb[i] = buffer[used - i - 1];
      }
      rb[used] = '\0';
    } else {
      rb[0] = '\0';
      hsm_et_error_set(ec, HE_ERROR_INVALID_ARGS);
    }
  } else {
    hsm_et_error_set(ec, HE_ERROR_INVALID_ARGS);
  }
  return back;
}


/* vim: set ai sw=4 ts=4 expandtab : */

