/** @file   ex057.c Beispielprogramm fuer Zeiger und Felder von Strukturen.
*/

/* Copyright (C) 2014-2017 - HS Schmalkalden. All rights reserved. */

#include <stdio.h>

/**	Ein geometrischer Punkt.
*/
typedef struct {
	double	x;	/**< X-Koordinate. */
	double	y;	/**< Y-Koordinate. */
} PUNKT;

/**	Eine Linie.
*/
typedef struct {
	PUNKT	P0;		/**< Anfangspunkt. */
	PUNKT	P1;		/**< Endpunkt. */
} LINIE;

/**	Rechteck.
*/
typedef struct {
	double	xmin;	/**< Linker x-Wert. */
	double	xmax;	/**< Rechter x-Wert. */
	double	ymin;	/**< Unterer y-Wert. */
	double	ymax;	/**< Oberer y-Wert. */
} RECHTECK;

/**	Konstante Variable vom Typ Rechteck.
*/
static const RECHTECK test_re = { 0.0, 10.0, 0.0, 12.0 };

/**	Feld mit mehreren Variablen vom Typ Linie.
	Jede Linie besteht ihrerseits aus 2 Punkten.
	Jeder dieser Punkte wiederum besteht aus x- und y-Wert.
*/
static const LINIE linien[] = {
	{{  1.0,  1.0 }, {  9.0,  9.0 }}, /* Erste Linie, bestehend aus P0 und P1 */
	{{  2.0, 11.0 }, {  7.0,  8.0 }}, /* Naechste Linie ... */
	{{  4.0,  3.0 }, {  9.5,  9.3 }},
	{{ -1.0,  2.0 }, { 10.5, 10.5 }},
	{{  8.5,  8.5 }, {  2.0,  2.0 }},
	{{  5.5,  6.5 }, {  7.5,  8.3 }},
	{{  3.0, 13.0 }, {  7.0, 13.5 }},
	{{  1.0,  9.8 }, {  8.0,  1.0 }},
	{{ -3.0,  4.2 }, { 13.0,  4.4 }},
	{{  1.0,  2.0 }, {  3.0,  4.0 }}
};

/**	Anzahl der Linien im Feld linien.
	Zur Ermittelung der Anzahl wird die Gesamtgroesse der
	Variable linien durch die Groesse des Typs dividiert.
*/
static const size_t anzahl_linien = sizeof(linien)/sizeof(LINIE);

/**	Pruefe im Punkt im Rechteck oder auf dessen Rand liegt.
	@param	p	Zu pruefender Punkt.
	@param	r	Rechteck, in oder auf dessen Rand der Punkt liegen soll.
	@return	1 wenn der Punkt im Rechteck liegt, ansonsten 0.
*/
static
int
punkt_im_rechteck(const PUNKT *p, const RECHTECK *r)
{
	int	res	= 0;
	if((???) && (???) && (???) && (???)) {
		res = 1;
	}
	return res;
}

/**	Pruefe, ob Linie vollstaendig im Rechteck oder auf
	dessen Rand liegt (also
	keinen Punkt ausserhalb des Rechtecks hat).
	@param	p	Zu pruefende Linie.
	@param	r	Rechteck, in dem die Linie liegen soll.
	@return	1 wenn Linie im Rechteck liegt, ansonsten 0.
*/
static
int
linie_im_rechteck(const LINIE *p, const RECHTECK *r)
{
	int		res	= 0;
	if(punkt_im_rechteck(???, ???)) {
		if(punkt_im_rechteck(???, ???)) {
			res = 1;
		}
	}
	return res;
}

/** Hauptprogramm.
	@return 0 bei Erfolg.
*/
int
main(void)
{
	LINIE const	*pl		= NULL;	/* Zeiger auf aktuelle Linie */
	size_t	 i;			/* Index aktuelle Linie */
	int		 im_rechteck	= 0;	/* Anzahl Linien im Rechteck */

	/*	Zeiger auf Feldanfang setzen
	*/
	pl = linien;

	/*	Feld durchmustern, dabei fuer jede Linie pruefen, ob
	sie im Rechteck liegt.
	Falls ja, dann Ergebniszaehler erhoehen.
	*/
	for(i = 0; i < anzahl_linien; i++) {
		if(linie_im_rechteck(???, ???)) {
			im_rechteck++;
		}
		pl++;
	}

	/*	Ergebnis ausgeben
	*/
	printf("%d Linien liegen vollstaendig im Rechteck.\n", im_rechteck);
	return 0;
}

/* vim: set ai sw=4 ts=4 : */
