/** @file   ex064.c Beispielprogramm binaeres Schreiben.
*/

/* Copyright (C) 2014-2017 - HS Schmalkalden. All rights reserved. */

#ifdef _WIN32
#define _CRT_SECURE_NO_WARNINGS 1
#endif

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>
#include <stdint.h>
#include <limits.h>

#include "he-read.h"


/** Name der zu schreibenden Datei.
*/
static const char filename[] = {
#ifdef _WIN32
"C:\\Temp\\C\\ex064.dat"
#else
"ex064.dat"
#endif
};


/** Hauptprogramm.
		@return 0 bei Erfolg.
*/
int
main(void)
{
	FILE      *outf   =   NULL;   /* Ausgabedatei */
	double    *werte  =   NULL;   /* Puffer fuer die Werte */
	int        exc    =   1;      /* Exit-Status */
	int        num    =   0;      /* Anzahl der Werte */
	int        i;                 /* Index fuer aktuell einzulesenden Wert */

	/* Anzahl der Werte einlesen */
	if (0 == hsm_et_read_int("Anzahl der Werte: ", &num)) {
		goto finished;
	}

	/* Werte-Anzahl pruefen (positiv, aber kein Ueberlauf) */
	if (1 > num) {
		fputs("FEHLER: Die Werte-Anzahl muss mindestens 1 sein!\n", stderr);
		fflush(stderr);
		goto finished;
	}
	if ((SIZE_MAX / sizeof(double)) < (size_t)num) {
		fputs("FEHLER: Zu viele Werte!\n", stderr);
		fflush(stderr);
		goto finished;
	}

	/* Speicher anfordern und Ergebnis pruefen */
	werte = (double *)calloc( (size_t)num, sizeof(double) );
	if (NULL == werte) {
		fputs("FEHLER: Kein Speicher verfuegbar!\n", stderr);
		fflush(stderr);
		goto finished;
	}

	/* Werte einlesen */
	for (i = 0; i < num; i++) {
		printf("Bitte Wert %d eingeben: ", (i+1));
		if (0 == hsm_et_read_double(NULL, &(werte[i]))) {
			goto finished;
		}
	}

	/* Datei oeffnen, binaeres Schreiben */
	??? = fopen(???, ???);
	if (NULL == outf) {
		i = errno;
		fprintf(stderr, "FEHLER: Datei \"%s\" nicht geoeffnet!\n", filename);
		errno = i;
		perror("fopen");
		goto finished;
	}

	/* Anzahl der Datensaetze schreiben */
	if(1 != fwrite(&num, sizeof(int), ???, outf)) {
		i = errno;
		fputs("FEHLER: Schreiben in Datei fehlgeschlagen!\n", stderr);
		fflush(stderr);
		errno = i;
		perror("fwrite");
		goto finished;
	}

	/* Daten schreiben */
	if ((size_t)num != fwrite(werte, sizeof(???), ???, outf)) {
		i = errno;
		fputs("FEHLER: Schreiben in Datei fehlgeschlagen!\n", stderr);
		fflush(stderr);
		errno = i;
		perror("fwrite");
		goto finished;
	}

	/* Erfolg in Exit-Status vermerken */
	exc = 0;

	/*	Aufraeumarbeiten und Programmende.
	----------------------------------
	*/
finished:
	/*	Ausgabedatei schliessen, falls erfolgreich geoeffnet.
	*/
	if (NULL != ???) {
		if (0 != fclose(???)) {
			exc = 1;
		}
	}
	/*	Dynamisch allozierten Speicher wieder freigeben, falls erhalten.
	*/
	if (NULL != werte) {
		free(werte);
	}
	/*	Programm beenden.
	*/
	exit(exc); return exc;
}

/* vim: set ai sw=4 ts=4 : */
