/**	@file	he-error.h	Fehlercodes.

	Hier werden Fehlercodes definiert, die bei der Arbeit mit
	den hsm_et_xxx()-Funktionen auftreten koennen.

	@code
	  int		ec;

	  ec = HE_ERROR_NONE;
	  function1(..., &ec);
	  funktion2(..., &ec);
	  ...
	  funktionn(..., &ec);
	  if (HE_ERROR_NONE == ec) {
	    ...
	  } else {
	    switch(ec) {
	      case HE_ERROR_INVALID_ARGS: {
	        ...
	      } break;
	      case HE_ERROR_MATH_OVERFLOW: {
	        ...
	      } break;
	      ...
	    }
	  }
	@endcode
*/

/* Copyright (C) 2014 - HS Schmalkalden. All rights reserved. */

#ifndef	HE_ERROR_INCLUDED
#define	HE_ERROR_INCLUDED	1

/**	@defgroup	hsm_et_error	Fehlercodes.
*/
/**@{*/

enum {
    /**	Kein Fehler aufgetreten
    */
    HE_ERROR_NONE	=	0,

    /**	Fehler in Systemfunktion, siehe errno.
    */
    HE_ERROR_SYSTEM,

    /**	Fehlerhafte Argumente wurden an Funktion uebergeben.
    */
    HE_ERROR_INVALID_ARGS,

    /**	Zahlenbereichsueberlauf bei mathematischer Operation.
    */
    HE_ERROR_MATH_OVERFLOW,

    /**	Division durch 0.
    */
    HE_ERROR_MATH_DIVZERO,

    /** Fehler beim Lesen/Schreiben in Datei.
    */
    HE_ERROR_IO,

    /** Fehlerhafter Eingabe-Text.
    */
    HE_ERROR_SYNTAX,

    /** Text zu gross fuer Puffer
    */
    HE_ERROR_BUFFERSIZE,

    /** Dynamische Speicherbeschaffung fehlgeschlagen.
    */
    HE_ERROR_MEMORY,
};


#ifdef __cplusplus
extern "C" {
#endif

/** Fehlercode in Variable eintragen.
    Der neue Fehlercode wird nur eingetragen, falls noch kein
    Fehler vermerkt war.
    @param  ptr Zeiger auf Fehlercode-Variable, darf NULL sein.
    @param  ec  Einzutragender Fehlercode.
*/
void
hsm_et_error_set(int *ptr, int ec);

#ifdef __cplusplus
};
#endif

/**@}*/
#endif

/* vim: set ai sw=4 ts=4 expandtab : */

