/**	@file   he-file.h   Funktionen fuer die Arbeit mit Dateien.

	Die Funktionen in diesem Modul geben Fehlermeldungen in
	deutscher Sprache aus, evtl. noch die vom System bereitgestellten
	Fehlermeldungen.
	Wird als letzter Parameter eine gültige Adresse einer
	Fehlercode-Variable mit uebergeben, wird bei Fehlern auch diese
	Variable gesetzt.
*/

/* Copyright (C) 2014 - HS Schmalkalden. All rights reserved. */

#ifndef HE_FILE_H_INCLUDED
#define HE_FILE_H_INCLUDED  1

#include "he-conf.h"

#include <stdio.h>

#if HAVE_STDINT_H
#ifndef STDINT_H_INCLUDED
#include <stdint.h>
#define STDINT_H_INCLUDED 1
#endif
#endif


#ifdef __cplusplus
extern "C" {
#endif

/** Datei oeffnen.
    @param  name    Dateiname.
    @param  mode    Datei-Mode.
    @param  ec      Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return Zeiger auf geoeffnete Datei bei Erfolg, NULL bei Fehler.
*/
FILE *
hsm_et_file_open(const char *name, const char *mode, int *ec);

/** Datei schliessen.
    @param  fp      Dateizeiger von fopen() oder hsm_et_file_open().
    @param  name    Dateiname, darf NULL sein.
    @param  ec      Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return 1 bei Erfolg, 0 bei Fehler.
*/
int
hsm_et_file_close(FILE *fp, const char *name, int *ec);

/** String in Datei schreiben.
    @param  fp      Dateizeiger von fopen() oder hsm_et_file_open().
    @param  src     Der zu schreibende String.
    @param  name    Dateiname, darf NULL sein.
    @param  ec      Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return 1 bei Erfolg, 0 bei Fehler.
*/
int
hsm_et_file_puts(FILE *fp, const char *src, const char *name, int *ec);

/** Dateigroesse ermitteln.
    @param  szptr   Zeiger auf Variable, in der Dateigroesse gespeichert wird.
    @param  name    Dateiname.
    @param  ec      Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return 1 bei Erfolg, 0 bei Fehler.
*/
int
hsm_et_file_size(size_t *szptr, const char *name, int *ec);

/** Dateigroesse ermitteln.
    @param  szptr   Zeiger auf Variable fuer Ergebnis.
    @param  fp      FILE-Zeiger fuer bereits geoeffnete Datei.
    @param  name    Dateiname, darf NULL sein.
    @param  ec      Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return 1 bei Erfolg, 0 bei Fehler.
*/
int
hsm_et_file_pointer_size(size_t *szptr, FILE *fp, const char *name, int *ec);

#ifdef __cplusplus
}
#endif

#endif
/* ifndef HE_FILE_H_INCLUDED */

/* vim: set ai sw=4 ts=4 expandtab : */

