/**	@file   he-long.h   Mathematische Operationen
	mit long-Werten, Erkennung von Ueberlauf, Vorbeugung vor Division
	durch 0.
*/

/* Copyright (C) 2014 - HS Schmalkalden. All rights reserved. */

#ifndef HE_LONG_H_INCLUDED
#define	HE_LONG_H_INCLUDED 1


#ifdef __cplusplus
extern "C" {
#endif

/** Addition.
    @param	a	Linker Operand.
    @param	b	Rechter Operand.
    @param	ec	Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return	Ergebnis.
*/
long
hsm_et_long_add(long a, long b, int *ec);

/** Subtraktion.
    @param	a	Linker Operand.
    @param	b	Rechter Operand.
    @param	ec	Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return	Ergebnis.
*/
long
hsm_et_long_sub(long a, long b, int *ec);

/** Multiplikation.
    @param	a	Linker Operand.
    @param	b	Rechter Operand.
    @param	ec	Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return	Ergebnis.
*/
long
hsm_et_long_mul(long a, long b, int *ec);

/** Division.
    @param	a	Zaehler.
    @param	b	Nenner.
    @param	ec	Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return	Ergebnis.
*/
long
hsm_et_long_div(long a, long b, int *ec);

/** Betrag bilden.
    @param	a	Linker Operand.
    @param	ec	Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return	Ergebnis.
*/
long
hsm_et_long_abs(long a, int *ec);

/** Quadrieren.
    @param	a	Linker Operand.
    @param	ec	Zeiger auf Fehlercode-Variable, darf NULL sein.
    @return	Ergebnis.
*/
long
hsm_et_long_sqr(long a, int *ec);

#ifdef __cplusplus
}
#endif

#endif
/* ifndef HE_LONG_H_INCLUDED */

/* vim: set ai sw=4 ts=4 expandtab : */

